@@ -1,6 +1,6 @@
 
 (function main(){
-	let groups = find_groups(["Hjson", "TOML"]);
+	let groups = find_groups(["Hjson", "JSON", "TOML"]);
 	console.log("groups:", groups);
 	for (let group of groups) {
 		add_tabs(group);
@@ -14,12 +14,11 @@ function find_groups(langs) {
 	let groups = [];
 	$("code").each(function(){
 		let lang = langs.find(
-			lang => this.className.split(' ')
-				.map(c => c.toLowerCase())
-				.includes(lang.toLowerCase())
-			);
+			lang => this.className.toLowerCase().split(/[ -]/).includes(lang.toLowerCase())
+		);
 		if (!lang) return;
 		let pre = this.parentElement;
+		pre.classList.add("tabbed");
 		let last_group = groups[groups.length-1];
 		let item = { lang, pre };
 		if (last_group) {
